metrics_handler

Function metrics_handler 

pub async fn metrics_handler(metrics: Arc<PrometheusMetrics>) -> MetricsResponse
Handles GET /metrics requests

Returns metrics in Prometheus text format with appropriate content-type header. This is a testable version of the handler that returns a struct.