pub struct PrometheusService { /* private fields */ }Implementations
Sourceimpl PrometheusService
impl PrometheusService
pub fn new(addr: SocketAddr) -> Self
Sourcepub fn port(&self) -> u16
pub fn port(&self) -> u16
Returns the actual port the server is listening on (after start())
Returns 0 if the service hasn’t been started yet.
Sourcepub fn port_accessor(&self) -> Arc<AtomicU16> ⓘ
pub fn port_accessor(&self) -> Arc<AtomicU16> ⓘ
Returns a cloneable accessor for the bound port.
Use this when you need to read the port after the service has been moved into a CamelContext or other container.
Sourcepub fn set_health_checker(
&mut self,
checker: Arc<dyn Fn() -> HealthReport + Send + Sync>,
)
pub fn set_health_checker( &mut self, checker: Arc<dyn Fn() -> HealthReport + Send + Sync>, )
Set the health checker closure that will be called to get system health.
The closure should capture a reference to CamelContext’s health_check method.
Sourcepub fn health_checker(
&self,
) -> Option<Arc<dyn Fn() -> HealthReport + Send + Sync>>
pub fn health_checker( &self, ) -> Option<Arc<dyn Fn() -> HealthReport + Send + Sync>>
Get a clone of the health checker if one is set.