pub struct PrometheusService { /* private fields */ }Implementations
Sourceimpl PrometheusService
impl PrometheusService
pub fn new(addr: SocketAddr) -> Self
Sourcepub fn port(&self) -> u16
pub fn port(&self) -> u16
Returns the actual port the server is listening on (after start())
Returns 0 if the service hasn’t been started yet.
Sourcepub fn port_accessor(&self) -> Arc<AtomicU16>
pub fn port_accessor(&self) -> Arc<AtomicU16>
Returns a cloneable accessor for the bound port.
Use this when you need to read the port after the service has been moved into a CamelContext or other container.
pub fn status_arc(&self) -> Arc<AtomicU8>
pub fn set_health_source(&mut self, source: Arc<dyn HealthSource>)
pub fn health_source(&self) -> Option<Arc<dyn HealthSource>>